@@ -1,7 +1,5 @@
 extern crate bindgen;
 
-#[cfg(target_os = "macos")]
-use pkg_config;
 use std::env;
 use std::path::PathBuf;
 #[cfg(windows)]
@@ -52,7 +50,7 @@ fn find_leptonica_system_lib() -> Option<String> {
 // we can use leptonica installed anywhere on Linux.
 // if you change install path(--prefix) to `configure` script.
 // set `export PKG_CONFIG_PATH=/path-to-lib/pkgconfig` before.
-#[cfg(any(target_os = "macos", target_os = "linux"))]
+#[cfg(any(target_os = "macos", target_os = "linux", target_os = "freebsd"))]
 fn find_leptonica_system_lib() -> Option<String> {
     let pk = pkg_config::Config::new().probe("lept").unwrap();
     // Tell cargo to tell rustc to link the system proj shared library.
@@ -66,7 +64,12 @@ fn find_leptonica_system_lib() -> Option<String> {
     Some(include_path.to_str().unwrap().into())
 }
 
-#[cfg(all(not(windows), not(target_os = "macos"), not(target_os = "linux")))]
+#[cfg(all(
+    not(windows),
+    not(target_os = "macos"),
+    not(target_os = "linux"),
+    not(target_os = "freebsd")
+))]
 fn find_leptonica_system_lib() -> Option<String> {
     println!("cargo:rustc-link-lib=lept");
     None
@@ -77,6 +80,11 @@ fn main() {
 
     let mut bindings = bindgen::Builder::default().header("wrapper.h");
 
+    #[cfg(windows)]
+    {
+        bindings = bindings.clang_args(["-x", "c++"]);
+    }
+
     if let Some(include_path) = clang_extra_include {
         bindings = bindings.clang_arg(format!("-I{}", include_path));
     }
